[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples

变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
  保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
  async_reduce, custom_temporary_allocation, explicit_cuda_stream,
  global_device_vector, range_view, unwrap_pointer, wrap_pointer, device

结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
  27/27 tuning headers, 78 benchmarks, 243 tests,
  60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
muh-bot
2026-08-03 12:39:26 +00:00
parent a2a5dd8f00
commit 24ef6a91b5
5439 changed files with 0 additions and 719516 deletions

View File

@@ -1,139 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#include <cuda/devices>
#include <cuda/hierarchy>
#include <cuda/launch>
#include <cuda/stream>
#include <cuda/experimental/coop.cuh>
#include <cuda/experimental/group.cuh>
#include "testing.cuh"
template <class Group>
__device__ void test_group(const Group& group)
{
// Single value tests.
{
// Test all threads with false.
{
const auto result = cudax::coop::any_of(group, false);
REQUIRE(result.has_value());
if (result.has_value())
{
REQUIRE(!result.value());
}
}
// Test all threads with true.
{
const auto result = cudax::coop::any_of(group, true);
REQUIRE(result.has_value());
if (result.has_value())
{
REQUIRE(result.value());
}
}
}
{
// Test all threads with false (broadcasted).
{
const bool result = cudax::coop::any_of(cudax::broadcasted, group, false);
REQUIRE(!result);
}
// Test all threads with true (broadcasted).
{
const bool result = cudax::coop::any_of(cudax::broadcasted, group, true);
REQUIRE(result);
}
}
// Array tests.
{
// Test all threads with false.
{
bool in[]{false, false, false};
const auto result = cudax::coop::any_of(group, in);
REQUIRE(result.has_value());
if (result.has_value())
{
REQUIRE(!result.value());
}
}
// Test all threads with true.
{
bool in[]{true, true, true, true};
const auto result = cudax::coop::any_of(group, in);
REQUIRE(result.has_value());
if (result.has_value())
{
REQUIRE(result.value());
}
}
// Test all threads except 1 with false.
{
bool in[]{false, false, true};
const auto result = cudax::coop::any_of(group, in);
REQUIRE(result.has_value());
if (result.has_value())
{
REQUIRE(result.value());
}
}
// Test all threads with false (broadcasted).
{
bool in[]{false, false, false};
const bool result = cudax::coop::any_of(cudax::broadcasted, group, in);
REQUIRE(!result);
}
// Test all threads with true (broadcasted).
{
bool in[]{true, true, true, true};
const bool result = cudax::coop::any_of(cudax::broadcasted, group, in);
REQUIRE(result);
}
// Test all threads except 1 with false (broadcasted).
{
bool in[]{false, false, true};
const bool result = cudax::coop::any_of(cudax::broadcasted, group, in);
REQUIRE(result);
}
}
}
struct TestKernel
{
template <class Config>
__device__ void operator()(const Config& config)
{
test_group(cudax::this_thread{});
test_group(cudax::this_thread{config});
}
};
C2H_TEST("any_of/this_thread", "[any_of][this_thread]")
{
const auto device = cuda::devices[0];
const cuda::stream stream{device};
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims<32>());
cuda::launch(stream, config, TestKernel{});
stream.sync();
}

View File

@@ -1,156 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#include <cuda/devices>
#include <cuda/hierarchy>
#include <cuda/launch>
#include <cuda/stream>
#include <cuda/experimental/coop.cuh>
#include <cuda/experimental/group.cuh>
#include "testing.cuh"
template <class Group>
__device__ void test_group(const Group& group)
{
const auto my_rank = cuda::gpu_thread.rank_as<unsigned>(group);
// Single value tests.
{
// Test all threads with false.
{
const auto result = cudax::coop::any_of(group, false);
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(!result.value());
}
}
// Test all threads with true.
{
const auto result = cudax::coop::any_of(group, true);
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(result.value());
}
}
// Test all threads except 1 with false.
{
const auto result = cudax::coop::any_of(group, (my_rank == cuda::gpu_thread.count_as<unsigned>(group) - 1));
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(result.value());
}
}
// Test all threads with false (broadcasted).
{
const bool result = cudax::coop::any_of(cudax::broadcasted, group, false);
REQUIRE(!result);
}
// Test all threads with true (broadcasted).
{
const bool result = cudax::coop::any_of(cudax::broadcasted, group, true);
REQUIRE(result);
}
// Test all threads except 1 with false (broadcasted).
{
const bool result =
cudax::coop::any_of(cudax::broadcasted, group, (my_rank == cuda::gpu_thread.count_as<unsigned>(group) - 1));
REQUIRE(result);
}
}
// Array tests.
{
// Test all threads with false.
{
bool in[]{false, false, false};
const auto result = cudax::coop::any_of(group, in);
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(!result.value());
}
}
// Test all threads with true.
{
bool in[]{true, true, true, true};
const auto result = cudax::coop::any_of(group, in);
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(result.value());
}
}
// Test all threads except 1 with false.
{
bool in[]{false, false, my_rank == cuda::gpu_thread.count_as<unsigned>(group) - 1};
const auto result = cudax::coop::any_of(group, in);
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(result.value());
}
}
// Test all threads with false (broadcasted).
{
bool in[]{false, false, false};
const bool result = cudax::coop::any_of(cudax::broadcasted, group, in);
REQUIRE(!result);
}
// Test all threads with true (broadcasted).
{
bool in[]{true, true, true, true};
const bool result = cudax::coop::any_of(cudax::broadcasted, group, in);
REQUIRE(result);
}
// Test all threads except 1 with false (broadcasted).
{
bool in[]{false, false, my_rank == cuda::gpu_thread.count_as<unsigned>(group) - 1};
const bool result = cudax::coop::any_of(cudax::broadcasted, group, in);
REQUIRE(result);
}
}
}
struct TestKernel
{
template <class Config>
__device__ void operator()(const Config& config)
{
test_group(cudax::this_warp{});
test_group(cudax::this_warp{config});
}
};
C2H_TEST("any_of/this_warp", "[any_of][this_warp]")
{
const auto device = cuda::devices[0];
const cuda::stream stream{device};
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims<32>());
cuda::launch(stream, config, TestKernel{});
stream.sync();
}

View File

@@ -1,187 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDA Experimental in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
#include <cuda/devices>
#include <cuda/hierarchy>
#include <cuda/launch>
#include <cuda/stream>
#include <cuda/experimental/coop.cuh>
#include <cuda/experimental/group.cuh>
#include "testing.cuh"
template <class Group>
__device__ void test_group(const Group& group)
{
// Exit all threads that are not part of the group.
if (!cuda::gpu_thread.is_part_of(group))
{
return;
}
const auto my_rank = cuda::gpu_thread.rank_as<unsigned>(group);
// Single value tests.
{
// Test all threads with false.
{
const auto result = cudax::coop::any_of(group, false);
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(!result.value());
}
}
// Test all threads with true.
{
const auto result = cudax::coop::any_of(group, true);
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(result.value());
}
}
// Test all threads except 1 with false.
{
const auto result = cudax::coop::any_of(group, (my_rank == cuda::gpu_thread.count_as<unsigned>(group) - 1));
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(result.value());
}
}
// Test all threads with false (broadcasted).
{
const bool result = cudax::coop::any_of(cudax::broadcasted, group, false);
REQUIRE(!result);
}
// Test all threads with true (broadcasted).
{
const bool result = cudax::coop::any_of(cudax::broadcasted, group, true);
REQUIRE(result);
}
// Test all threads except 1 with false (broadcasted).
{
const bool result =
cudax::coop::any_of(cudax::broadcasted, group, (my_rank == cuda::gpu_thread.count_as<unsigned>(group) - 1));
REQUIRE(result);
}
}
// Array tests.
{
// Test all threads with false.
{
bool in[]{false, false, false};
const auto result = cudax::coop::any_of(group, in);
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(!result.value());
}
}
// Test all threads with true.
{
bool in[]{true, true, true, true};
const auto result = cudax::coop::any_of(group, in);
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(result.value());
}
}
// Test all threads except 1 with false.
{
bool in[]{false, false, my_rank == cuda::gpu_thread.count_as<unsigned>(group) - 1};
const auto result = cudax::coop::any_of(group, in);
REQUIRE(result.has_value() == (my_rank == 0));
if (result.has_value())
{
REQUIRE(result.value());
}
}
// Test all threads with false (broadcasted).
{
bool in[]{false, false, false};
const bool result = cudax::coop::any_of(cudax::broadcasted, group, in);
REQUIRE(!result);
}
// Test all threads with true (broadcasted).
{
bool in[]{true, true, true, true};
const bool result = cudax::coop::any_of(cudax::broadcasted, group, in);
REQUIRE(result);
}
// Test all threads except 1 with false (broadcasted).
{
bool in[]{false, false, my_rank == cuda::gpu_thread.count_as<unsigned>(group) - 1};
const bool result = cudax::coop::any_of(cudax::broadcasted, group, in);
REQUIRE(result);
}
}
}
struct CustomBinaryPartition
{
template <class MappingResult>
__device__ bool operator()(MappingResult mapping_result)
{
switch (mapping_result.unit_rank())
{
case 1:
case 5:
case 14:
case 15:
case 31:
return true;
default:
return false;
}
}
};
struct TestKernel
{
template <class Config>
__device__ void operator()(const Config& config)
{
const cudax::this_warp warp{config};
test_group(cudax::group{cuda::gpu_thread, warp, cudax::identity_mapping{}, cudax::lane_synchronizer{}});
test_group(cudax::group{cuda::gpu_thread, warp, cudax::group_by<4>{}, cudax::lane_synchronizer{}});
test_group(cudax::group{cuda::gpu_thread, warp, cudax::group_by{1}, cudax::lane_synchronizer{}});
test_group(
cudax::group{cuda::gpu_thread, warp, cudax::group_by{3, cudax::non_exhaustive}, cudax::lane_synchronizer{}});
test_group(cudax::group{
cuda::gpu_thread, warp, cudax::binary_partition{CustomBinaryPartition{}}, cudax::lane_synchronizer{}});
}
};
C2H_TEST("any_of/threads_within_warp", "[any_of][threads_within_warp]")
{
const auto device = cuda::devices[0];
const cuda::stream stream{device};
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims<32>());
cuda::launch(stream, config, TestKernel{});
stream.sync();
}